import axios from 'axios'
// import Qs from 'qs'
import { Message } from 'element-ui'

// create an axios instance
const service = axios.create({
  baseURL: process.env.BASE_URL, // url = base url + request url
  // baseURL: '/other', // url = base url + request url
  // withCredentials: true, // send cookies when cross-domain requests
  timeout: 60000 // request timeout
  // transformRequest: data => {
  //   return Qs.stringify(data)
  // }
})

// request interceptor
service.interceptors.request.use(
  config => {
    // do something before request is sent
    // console.log(config)
    return config
  },
  error => {
    // do something with request error
    console.log(error) // for debug
    return Promise.reject(error)
  }
)

// response interceptor
service.interceptors.response.use(
  /**
   * If you want to get http information such as headers or status
   * Please return  response => response
  */

  /**
   * Determine the request status by custom code
   * Here is just an example
   * You can also judge the status by HTTP Status Code
   */
  response => {
    console.log(response)
    if (response.config.responseType === 'blob') {
      return response
    }

    return response.data
  },
  error => {
    if (error.response) {
      let message = error.response.data.message
      switch (error.response.status) {
        default:
          if (!error.response.data.message) {
            message = error.response.data
          }
          Message({
            message: message,
            type: 'error',
            duration: 2 * 1000
          })
          break
      }
    }
    console.log('error', error)
    return Promise.reject(error)
  }
)

export default service
